@@ -1,6 +1,6 @@
 /*
-   Copyright 2011-2012 ALT Linux
-   Copyright 2011-2012 Michael Pozhidaev
+   Copyright 2011-2013 ALT Linux
+   Copyright 2011-2013 Michael Pozhidaev
 
    This file is part of the Deepsolver.
 
@@ -101,108 +101,44 @@ void PkgUtils::prepareReversedMaps(const PackageScopeContent& content,
   logMsg(LOG_DEBUG, "Installed package requires/conflicts reversed map construction takes %f sec", installedDuration);
 }
 
-std::string PkgUtils::satToString(const AbstractPackageScope& scope, 
-	      const Sat& sat,
-	      const StringVector& annotations)
+void PkgUtils::fillUpgradeDowngrade(const AbstractPackageBackEnd& backEnd,
+				    const AbstractPackageScope& scope,
+				    VarIdVector& install,
+				    VarIdVector& remove,
+				    VarIdToVarIdMap& upgrade,
+				    VarIdToVarIdMap& downgrade)
 {
-  std::ostringstream ss;
-  for(Sat::size_type i = 0;i < sat.size();i++)
+  upgrade.clear();
+  downgrade.clear();
+  for(VarIdVector::size_type i = 0;i < install.size();i++)
     {
-      const Clause& clause = sat[i];
-      if (i < annotations.size())
-	ss << annotations[i] << std::endl;
-      ss << "(" << std::endl;
-	for(Clause::size_type k = 0;k < clause.size();k++)
-	  {
-	    const Lit& lit = clause[k];
-	    if (lit.neg)
-	      ss << " !"; else 
-	      ss << "  ";
-	    ss << scope.constructPackageNameWithBuildTime(lit.varId);
-	    if (k + 1 < clause.size())
-	      ss << " ||";
-	    ss << std::endl;
-	  }
-	ss << ")" << std::endl;
-	if (i + 1 < sat.size())
-	  {
-	    ss << std::endl;
-	    ss << "&&" << std::endl;
-	    ss << std::endl;
-	  }
-    }
-  return ss.str();
-}
-
-void PkgUtils::printSolution(const AbstractPackageScope& scope,
-			     const VarIdVector& install,
-			     const VarIdVector& remove)
-{
-  std::cout << std::endl;
-  std::cout << install.size() << " packages to install, " << remove.size() << " packages to remove" << std::endl;
-  if (!install.empty())
-    {
-      std::cout << std::endl;
-      std::cout << "The following packages must be installed:" << std::endl;
-      StringVector v;
-      for(size_t k = 0;k < install.size();k++)
-	v.push_back(scope.constructPackageName(install[k]));
-      printThreeColumns(v);
-    }
-  if (!remove.empty())
-    {
-      StringVector v;
-      std::cout << std::endl;
-      std::cout << "The following packages must be removed:" << std::endl;
-      for(size_t k = 0;k < remove.size();k++)
-	v.push_back(scope.constructPackageName(remove[k]));
-      printThreeColumns(v);
-      std::cout << std::endl;
-    }
-}
-
-void printThreeColumns(const StringVector& items)
-{
-  StringVector v = items;
-  std::sort(v.begin(), v.end());
-  if (v.empty())
-    return;
-  StringVector v1, v2, v3;
-  for(StringVector::size_type i = 0;i < v.size();i += 3)
-    {
-      v1.push_back(v[i]);
-      if (i + 1 < v.size())
-	v2.push_back(v[i + 1]);
-      if (i + 2 < v.size())
-	v3.push_back(v[i + 2]);
-    }
-  std::string::size_type maxLen1 = 0, maxLen2 = 0;
-  for(StringVector::size_type i = 0;i < v1.size();i++)
-    if (v1[i].length() > maxLen1)
-      maxLen1 = v1[i].length();
-  for(StringVector::size_type i = 0;i < v2.size();i++)
-    if (v2[i].length() > maxLen2)
-      maxLen2 = v2[i].length();
-  assert(maxLen1 > 0 && (v2.empty() || maxLen2 > 0));
-  for(StringVector::size_type i = 0;i < v3.size();i++)
-    {
-      std::cout << v1[i];
-      for(std::string::size_type k = v1[i].length();k < maxLen1 + 2;k++)
-	std::cout << " ";
-      std::cout << v2[i];
-      for(std::string::size_type k = v2[i].length();k < maxLen2 + 2;k++)
-	std::cout << " ";
-      std::cout << v3[i] << std::endl;
-    }
-  if (v1.size() > v3.size())
-    {
-      std::cout << v1[v1.size() - 1];
-      if (v2.size() > v3.size())
-	{
-	  for(std::string::size_type k = v1[v1.size() - 1].length();k < maxLen1 + 2;k++)
-	    std::cout << " ";
-	  std::cout << v2[v2.size() - 1];
-	}
-      std::cout << std::endl;
+      if (install[i] == BAD_VAR_ID)
+	continue;
+      VarIdVector::size_type j;
+      for(j = 0;j < remove.size();j++)
+	if (remove[j] != BAD_VAR_ID && scope.packageIdOfVarId(remove[j]) == scope.packageIdOfVarId(install[i]))
+	  break;
+      if (j >= remove.size())
+	continue;
+      const std::string versionToInstall = scope.getVersion(install[i]);
+      const std::string versionToRemove = scope.getVersion(remove[j]);
+      assert(!backEnd.versionEqual(versionToInstall, versionToRemove));
+      if (backEnd.versionGreater(versionToInstall, versionToRemove))
+	upgrade.insert(VarIdToVarIdMap::value_type(remove[j], install[i])); else
+	downgrade.insert(VarIdToVarIdMap::value_type(remove[j], install[i]));
+      install[i] = BAD_VAR_ID;
+      remove[j] = BAD_VAR_ID;
     }
+  for(VarIdVector::size_type i = 0;i < install.size();i++)
+    while (i < install.size() && install[i] == BAD_VAR_ID)
+      {
+	install[i] = install.back();
+	install.pop_back();
+      }
+  for(VarIdVector::size_type i = 0;i < remove.size();i++)
+    while (i < remove.size() && remove[i] == BAD_VAR_ID)
+      {
+	remove[i] = remove.back();
+	remove.pop_back();
+      }
 }
