@@ -1,6 +1,6 @@
 /*
-   Copyright 2011-2012 ALT Linux
-   Copyright 2011-2012 Michael Pozhidaev
+   Copyright 2011-2013 ALT Linux
+   Copyright 2011-2013 Michael Pozhidaev
 
    This file is part of the Deepsolver.
 
@@ -21,6 +21,7 @@
 #include"ConfigCenter.h"
 #include"AbstractPackageRecipient.h"
 #include"repo/RepoParams.h"
+#include"PkgUrlsFile.h"
 
 class Repository
 {
@@ -54,13 +55,16 @@ public:
 
   void fetchInfoAndChecksum();
   void addIndexFilesForFetch(StringToStringMap& files);
+
   void loadPackageData(const StringToStringMap& files, 
 		       AbstractPackageRecipient& transactData,
+		       PkgUrlsFile& urlsFile,
 		       AbstractPackageRecipient& pkgInfoData);
 
 private:
   std::string buildInfoFileUrl() const;
   std::string buildChecksumFileUrl() const;
+  std::string buildBinaryPackageUrl(const PkgFile& pkgFile) const;
 
 private:
   std::string m_name, m_url, m_arch, m_component;
